==> libunistring-0.9.6.tar.xz: libunistring-0.9.6/lib/unictype/joininggroup_name.h <==
/* Arabic joining group of Unicode characters.
   Copyright (C) 2011-2015 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2011.

   This program is free software: you can redistribute it and/or modify it
   under the terms of the GNU Lesser General Public License as published
   by the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

ELEM (NONE,                  "No Joining Group")
ELEM (AIN,                   "Ain")
ELEM (ALAPH,                 "Alaph")
ELEM (ALEF,                  "Alef")
ELEM (BEH,                   "Beh")
ELEM (BETH,                  "Beth")
ELEM (BURUSHASKI_YEH_BARREE, "Burushaski Yeh Barree")
ELEM (DAL,                   "Dal")
ELEM (DALATH_RISH,           "Dalath Rish")
ELEM (E,                     "E")
ELEM (FARSI_YEH,             "Farsi Yeh")
ELEM (FE,                    "Fe")
ELEM (FEH,                   "Feh")
ELEM (FINAL_SEMKATH,         "Final Semkath")
ELEM (GAF,                   "Gaf")
ELEM (GAMAL,                 "Gamal")
ELEM (HAH,                   "Hah")
ELEM (HE,                    "He")
ELEM (HEH,                   "Heh")
ELEM (HEH_GOAL,              "Heh Goal")
ELEM (HETH,                  "Heth")
ELEM (KAF,                   "Kaf")
ELEM (KAPH,                  "Kaph")
ELEM (KHAPH,                 "Khaph")
ELEM (KNOTTED_HEH,           "Knotted Heh")
ELEM (LAM,                   "Lam")
ELEM (LAMADH,                "Lamadh")
ELEM (MEEM,                  "Meem")
ELEM (MIM,                   "Mim")
ELEM (NOON,                  "Noon")
ELEM (NUN,                   "Nun")
ELEM (NYA,                   "Nya")
ELEM (PE,                    "Pe")
ELEM (QAF,                   "Qaf")
ELEM (QAPH,                  "Qaph")
ELEM (REH,                   "Reh")
ELEM (REVERSED_PE,           "Reversed Pe")
ELEM (SAD,                   "Sad")
ELEM (SADHE,                 "Sadhe")
ELEM (SEEN,                  "Seen")
ELEM (SEMKATH,               "Semkath")
ELEM (SHIN,                  "Shin")
ELEM (SWASH_KAF,             "Swash Kaf")
ELEM (SYRIAC_WAW,            "Syriac Waw")
ELEM (TAH,                   "Tah")
ELEM (TAW,                   "Taw")
ELEM (TEH_MARBUTA,           "Teh Marbuta")
ELEM (TEH_MARBUTA_GOAL,      "Teh Marbuta Goal")
ELEM (TETH,                  "Teth")
ELEM (WAW,                   "Waw")
ELEM (YEH,                   "Yeh")
ELEM (YEH_BARREE,            "Yeh Barree")
ELEM (YEH_WITH_TAIL,         "Yeh With Tail")
ELEM (YUDH,                  "Yudh")
ELEM (YUDH_HE,               "Yudh He")
ELEM (ZAIN,                  "Zain")
ELEM (ZHAIN,                 "Zhain")
ELEM (ROHINGYA_YEH,          "Rohingya Yeh")
ELEM (STRAIGHT_WAW,          "Straight Waw")
ELEM (MANICHAEAN_ALEPH,      "Manichaean Aleph")
ELEM (MANICHAEAN_BETH,       "Manichaean Beth")
ELEM (MANICHAEAN_GIMEL,      "Manichaean Gimel")
ELEM (MANICHAEAN_DALETH,     "Manichaean Daleth")
ELEM (MANICHAEAN_WAW,        "Manichaean Waw")
ELEM (MANICHAEAN_ZAYIN,      "Manichaean Zayin")
ELEM (MANICHAEAN_HETH,       "Manichaean Heth")
ELEM (MANICHAEAN_TETH,       "Manichaean Teth")
ELEM (MANICHAEAN_YODH,       "Manichaean Yodh")
ELEM (MANICHAEAN_KAPH,       "Manichaean Kaph")
ELEM (MANICHAEAN_LAMEDH,     "Manichaean Lamedh")
ELEM (MANICHAEAN_DHAMEDH,    "Manichaean Dhamedh")
ELEM (MANICHAEAN_THAMEDH,    "Manichaean Thamedh")
ELEM (MANICHAEAN_MEM,        "Manichaean Mem")
ELEM (MANICHAEAN_NUN,        "Manichaean Nun")
ELEM (MANICHAEAN_SAMEKH,     "Manichaean Samekh")
ELEM (MANICHAEAN_AYIN,       "Manichaean Ayin")
ELEM (MANICHAEAN_PE,         "Manichaean Pe")
ELEM (MANICHAEAN_SADHE,      "Manichaean Sadhe")
ELEM (MANICHAEAN_QOPH,       "Manichaean Qoph")
ELEM (MANICHAEAN_RESH,       "Manichaean Resh")
ELEM (MANICHAEAN_TAW,        "Manichaean Taw")
ELEM (MANICHAEAN_ONE,        "Manichaean One")
ELEM (MANICHAEAN_FIVE,       "Manichaean Five")
ELEM (MANICHAEAN_TEN,        "Manichaean Ten")
ELEM (MANICHAEAN_TWENTY,     "Manichaean Twenty")
ELEM (MANICHAEAN_HUNDRED,    "Manichaean Hundred")

==> libunistring-0.9.7.tar.xz: libunistring-0.9.7/lib/unictype/joininggroup_name.h <==
/* Arabic joining group of Unicode characters.
   Copyright (C) 2011-2016 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2011.

   This program is free software: you can redistribute it and/or
   modify it under the terms of either:

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at your
       option) any later version.

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at your
       option) any later version.

   or both in parallel, as here.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

ELEM (NONE,                  "No Joining Group")
ELEM (AIN,                   "Ain")
ELEM (ALAPH,                 "Alaph")
ELEM (ALEF,                  "Alef")
ELEM (BEH,                   "Beh")
ELEM (BETH,                  "Beth")
ELEM (BURUSHASKI_YEH_BARREE, "Burushaski Yeh Barree")
ELEM (DAL,                   "Dal")
ELEM (DALATH_RISH,           "Dalath Rish")
ELEM (E,                     "E")
ELEM (FARSI_YEH,             "Farsi Yeh")
ELEM (FE,                    "Fe")
ELEM (FEH,                   "Feh")
ELEM (FINAL_SEMKATH,         "Final Semkath")
ELEM (GAF,                   "Gaf")
ELEM (GAMAL,                 "Gamal")
ELEM (HAH,                   "Hah")
ELEM (HE,                    "He")
ELEM (HEH,                   "Heh")
ELEM (HEH_GOAL,              "Heh Goal")
ELEM (HETH,                  "Heth")
ELEM (KAF,                   "Kaf")
ELEM (KAPH,                  "Kaph")
ELEM (KHAPH,                 "Khaph")
ELEM (KNOTTED_HEH,           "Knotted Heh")
ELEM (LAM,                   "Lam")
ELEM (LAMADH,                "Lamadh")
ELEM (MEEM,                  "Meem")
ELEM (MIM,                   "Mim")
ELEM (NOON,                  "Noon")
ELEM (NUN,                   "Nun")
ELEM (NYA,                   "Nya")
ELEM (PE,                    "Pe")
ELEM (QAF,                   "Qaf")
ELEM (QAPH,                  "Qaph")
ELEM (REH,                   "Reh")
ELEM (REVERSED_PE,           "Reversed Pe")
ELEM (SAD,                   "Sad")
ELEM (SADHE,                 "Sadhe")
ELEM (SEEN,                  "Seen")
ELEM (SEMKATH,               "Semkath")
ELEM (SHIN,                  "Shin")
ELEM (SWASH_KAF,             "Swash Kaf")
ELEM (SYRIAC_WAW,            "Syriac Waw")
ELEM (TAH,                   "Tah")
ELEM (TAW,                   "Taw")
ELEM (TEH_MARBUTA,           "Teh Marbuta")
ELEM (TEH_MARBUTA_GOAL,      "Teh Marbuta Goal")
ELEM (TETH,                  "Teth")
ELEM (WAW,                   "Waw")
ELEM (YEH,                   "Yeh")
ELEM (YEH_BARREE,            "Yeh Barree")
ELEM (YEH_WITH_TAIL,         "Yeh With Tail")
ELEM (YUDH,                  "Yudh")
ELEM (YUDH_HE,               "Yudh He")
ELEM (ZAIN,                  "Zain")
ELEM (ZHAIN,                 "Zhain")
ELEM (ROHINGYA_YEH,          "Rohingya Yeh")
ELEM (STRAIGHT_WAW,          "Straight Waw")
ELEM (MANICHAEAN_ALEPH,      "Manichaean Aleph")
ELEM (MANICHAEAN_BETH,       "Manichaean Beth")
ELEM (MANICHAEAN_GIMEL,      "Manichaean Gimel")
ELEM (MANICHAEAN_DALETH,     "Manichaean Daleth")
ELEM (MANICHAEAN_WAW,        "Manichaean Waw")
ELEM (MANICHAEAN_ZAYIN,      "Manichaean Zayin")
ELEM (MANICHAEAN_HETH,       "Manichaean Heth")
ELEM (MANICHAEAN_TETH,       "Manichaean Teth")
ELEM (MANICHAEAN_YODH,       "Manichaean Yodh")
ELEM (MANICHAEAN_KAPH,       "Manichaean Kaph")
ELEM (MANICHAEAN_LAMEDH,     "Manichaean Lamedh")
ELEM (MANICHAEAN_DHAMEDH,    "Manichaean Dhamedh")
ELEM (MANICHAEAN_THAMEDH,    "Manichaean Thamedh")
ELEM (MANICHAEAN_MEM,        "Manichaean Mem")
ELEM (MANICHAEAN_NUN,        "Manichaean Nun")
ELEM (MANICHAEAN_SAMEKH,     "Manichaean Samekh")
ELEM (MANICHAEAN_AYIN,       "Manichaean Ayin")
ELEM (MANICHAEAN_PE,         "Manichaean Pe")
ELEM (MANICHAEAN_SADHE,      "Manichaean Sadhe")
ELEM (MANICHAEAN_QOPH,       "Manichaean Qoph")
ELEM (MANICHAEAN_RESH,       "Manichaean Resh")
ELEM (MANICHAEAN_TAW,        "Manichaean Taw")
ELEM (MANICHAEAN_ONE,        "Manichaean One")
ELEM (MANICHAEAN_FIVE,       "Manichaean Five")
ELEM (MANICHAEAN_TEN,        "Manichaean Ten")
ELEM (MANICHAEAN_TWENTY,     "Manichaean Twenty")
ELEM (MANICHAEAN_HUNDRED,    "Manichaean Hundred")
